==> qutim_0.2.60-maemo-13.tar.gz: qutim-0.2.60-maemo/translations/bg_BG/dbusnotifications.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>Author</name>
    <message>
        <location filename="../../qutim-meta/plugins/dbusnotifications/src/dplugin.cpp" line="+18"/>
        <source>Aleksey Sidorov</source>
        <translation>Алексей Сидоров</translation>
    </message>
</context>
<context>
    <name>DBusBackend</name>
    <message>
        <location filename="../../qutim-meta/plugins/dbusnotifications/src/dbusbackend.cpp" line="+130"/>
        <source>Open chat</source>
        <translation>Започване на разговор</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ignore</source>
        <translation>Пренебрегване</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Open</source>
        <translation>Отваряне</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../qutim-meta/plugins/dbusnotifications/src/dplugin.cpp" line="-4"/>
        <source>DBus notifications</source>
        <translation>DBus уведомления</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Notification system based on Freedesktop DBus protocol</source>
        <translation>Система за уведомления на базата на Freedesktop DBus протокола</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location line="+4"/>
        <source>Author</source>
        <translation>Автор</translation>
    </message>
</context>
<context>
    <name>plugin</name>
    <message>
        <location line="+3"/>
        <source>DBus notifications</source>
        <translation>DBus уведомления</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Notification system based on Freedesktop DBus protocol</source>
        <translation>Система за уведомления на базата на Freedesktop DBus протокола</translation>
    </message>
</context>
</TS>

==> qutim_0.2.80-maemo-13.tar.gz: qutim-0.2.80-maemo/translations/bg_BG/dbusnotifications.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>Author</name>
    <message>
        <location filename="../../qutim/plugins/dbusnotifications/src/dplugin.cpp" line="+18"/>
        <source>Sidorov Aleksey</source>
        <translation>Алексей Сидоров</translation>
    </message>
</context>
<context>
    <name>DBusBackend</name>
    <message>
        <location filename="../../qutim/plugins/dbusnotifications/src/dbusbackend.cpp" line="+60"/>
        <source>Show popup</source>
        <translation>Да се показва изскачащ прозорец</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../qutim/plugins/dbusnotifications/src/dplugin.cpp" line="-4"/>
        <source>DBus notifications</source>
        <translation>DBus уведомления</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Notification system based on Freedesktop DBus protocol</source>
        <translation>Система за уведомления на базата на Freedesktop DBus протокола</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location line="+4"/>
        <source>Author</source>
        <translation>Автор</translation>
    </message>
</context>
<context>
    <name>plugin</name>
    <message>
        <location line="+3"/>
        <source>DBus notifications</source>
        <translation>DBus уведомления</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Notification system based on Freedesktop DBus protocol</source>
        <translation>Система за уведомления на базата на Freedesktop DBus протокола</translation>
    </message>
</context>
</TS>
